@@ -1,25 +1,9 @@
-/****************************************************************************
-**
-** Copyright (C) 2007 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef HOSTPREFERENCES_H
 #define HOSTPREFERENCES_H
@@ -27,7 +11,7 @@
 #include "remoteview.h"
 #include "krdccore_export.h"
 
-#include <KConfigCore/KConfigGroup>
+#include <KConfigGroup>
 
 class QCheckBox;
 class QWidget;
@@ -51,6 +35,10 @@ public:
     bool windowedScale();
     void setWindowedScale(bool scale);
 
+    /** Whether scaling is enabled when session is full screen. Note: only windowedScale seems to be used. */
+    int scaleFactor();
+    void setScaleFactor(int factor);
+
     bool grabAllKeys();
     void setGrabAllKeys(bool grab);
 
